@@ -265,6 +265,7 @@ def plot_3D_Data(
 
     # Detect discontinuous axis (Norm_indices) to use flat shading
     is_shading_flat = False
+    flat_indices = []
     type_plot = "pcolor"
     for axis in axes_list:
         if axis.unit in self.axes[axis.index].normalizations:
@@ -272,9 +273,19 @@ def plot_3D_Data(
                 self.axes[axis.index].normalizations[axis.unit], Norm_indices
             ):
                 is_shading_flat = True
+                flat_indices.append(axis.index)
 
     if is_shading_flat:
         type_plot = "pcolormesh"
+        # 0.5 offset
+        if 0 in flat_indices:
+            Xdata = Xdata - 0.5
+            x_min -= 0.5
+            x_max -= 0.5
+        if 1 in flat_indices:
+            Ydata = Ydata - 0.5
+            y_min -= 0.5
+            y_max -= 0.5
         Ydata, Xdata = meshgrid(Ydata, Xdata)
 
     title4 = " for "
@@ -328,11 +339,7 @@ def plot_3D_Data(
                 thresh = 0.02
 
         if "dB" in unit:
-            indices = where(
-                Z_flat
-                > 10 * log10(thresh * self.normalizations["ref"].ref)
-                + abs(np_max(Zdata))
-            )[0]
+            indices = where(Z_flat > 10 * log10(thresh) + abs(np_max(Zdata)))[0]
         else:
             indices = where(Z_flat > abs(thresh * np_max(Zdata)))[0]
 
